/*
 * SPDX-FileCopyrightText: Stone Tickle <lattis@mochiro.moe>
 * SPDX-License-Identifier: GPL-3.0-only
 */

#ifndef FUNCTIONS_xxx_H
#define FUNCTIONS_xxx_H
#include "lang/func_lookup.h"

extern const struct func_impl impl_tbl_xxx[];
#endif
